@@ -2,13 +2,14 @@ package Auxiliary;
 use strict;
 use warnings;
 our ($VERSION, @ISA, @EXPORT_OK);
-$VERSION = '0.05';
+$VERSION = '0.05_01';
 require Exporter;
 @ISA         = qw(Exporter);
 @EXPORT_OK   = qw(
     _first_and_subsequent
 ); 
 *ok = *Test::More::ok;
+use lib ('.'); # where '.' => 't/'
 
 our (%eligibles, %chars);
 require "t/eligible_chars";
